@@ -1,20 +1,7 @@
 /*
-   Copyright (C) 2014-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2014-2020 Laurent Montel <montel@kde.org>
 
-   This program is free software; you can redistribute it and/or
-   modify it under the terms of the GNU General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with this program; see the file COPYING.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "followupreminderagent.h"
@@ -40,6 +27,7 @@
 
 FollowUpReminderAgent::FollowUpReminderAgent(const QString &id)
     : Akonadi::AgentBase(id)
+    , mManager(new FollowUpReminderManager(this))
 {
     Kdelibs4ConfigMigrator migrate(QStringLiteral("followupreminderagent"));
     migrate.setConfigFiles(QStringList() << QStringLiteral("akonadi_followupreminder_agentrc") << QStringLiteral("akonadi_followupreminder_agent.notifyrc"));
@@ -49,7 +37,6 @@ FollowUpReminderAgent::FollowUpReminderAgent(const QString &id)
     QDBusConnection::sessionBus().registerObject(QStringLiteral("/FollowUpReminder"), this, QDBusConnection::ExportAdaptors);
     const QString service = Akonadi::ServerManager::self()->agentServiceName(Akonadi::ServerManager::Agent, QStringLiteral("akonadi_followupreminder_agent"));
     QDBusConnection::sessionBus().registerService(service);
-    mManager = new FollowUpReminderManager(this);
     setNeedsNetwork(true);
 
     changeRecorder()->setMimeTypeMonitored(KMime::Message::mimeType());
@@ -72,8 +59,7 @@ FollowUpReminderAgent::FollowUpReminderAgent(const QString &id)
 }
 
 FollowUpReminderAgent::~FollowUpReminderAgent()
-{
-}
+= default;
 
 void FollowUpReminderAgent::setEnableAgent(bool enabled)
 {
