@@ -1,20 +1,7 @@
 /*
-   Copyright (C) 2014-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2014-2020 Laurent Montel <montel@kde.org>
 
-   This program is free software; you can redistribute it and/or
-   modify it under the terms of the GNU General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with this program; see the file COPYING.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "sendlaterconfigurewidget.h"
@@ -24,7 +11,6 @@
 #include <MessageComposer/SendLaterInfo>
 #include <MessageComposer/SendLaterDialog>
 
-#include <KConfigGroup>
 #include <KLocalizedString>
 #include <QMenu>
 #include <KMessageBox>
@@ -117,7 +103,7 @@ void SendLaterWidget::slotSendNow()
 {
     const QList<QTreeWidgetItem *> listItems = mWidget->treeWidget->selectedItems();
     if (listItems.count() == 1) {
-        SendLaterItem *mailItem = static_cast<SendLaterItem *>(listItems.first());
+        auto *mailItem = static_cast<SendLaterItem *>(listItems.first());
         Q_EMIT sendNow(mailItem->info()->itemId());
     }
 }
@@ -196,7 +182,7 @@ void SendLaterWidget::save()
 
     const int numberOfItem(mWidget->treeWidget->topLevelItemCount());
     for (int i = 0; i < numberOfItem; ++i) {
-        SendLaterItem *mailItem = static_cast<SendLaterItem *>(mWidget->treeWidget->topLevelItem(i));
+        auto *mailItem = static_cast<SendLaterItem *>(mWidget->treeWidget->topLevelItem(i));
         if (mailItem->info()) {
             SendLaterUtil::writeSendLaterInfo(config, mailItem->info());
         }
@@ -224,7 +210,7 @@ void SendLaterWidget::slotRemoveItem()
 
     for (QTreeWidgetItem *item : listItems) {
         if (removeMessage) {
-            SendLaterItem *mailItem = static_cast<SendLaterItem *>(item);
+            auto *mailItem = static_cast<SendLaterItem *>(item);
             if (mailItem->info()) {
                 Akonadi::Item::Id id = mailItem->info()->itemId();
                 if (id != -1) {
@@ -247,7 +233,7 @@ void SendLaterWidget::slotModifyItem()
         if (!item) {
             return;
         }
-        SendLaterItem *mailItem = static_cast<SendLaterItem *>(item);
+        auto *mailItem = static_cast<SendLaterItem *>(item);
 
         QPointer<MessageComposer::SendLaterDialog> dialog = new MessageComposer::SendLaterDialog(mailItem->info(), this);
         if (dialog->exec()) {
