@@ -1,20 +1,7 @@
 /*
-   Copyright (C) 2018 Daniel Vrátil <dvratil@kde.org>
+   SPDX-FileCopyrightText: 2018 Daniel Vrátil <dvratil@kde.org>
 
-   This program is free software; you can redistribute it and/or
-   modify it under the terms of the GNU General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with this program; see the file COPYING.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "../unifiedmailboxmanager.h"
@@ -379,7 +366,7 @@ private Q_SLOTS:
         Akonadi::Item item;
         item.setMimeType(QStringLiteral("application/octet-stream"));
         item.setParentCollection(inboxSourceCol);
-        item.setPayload(QByteArray{"Hello world!"});
+        item.setPayload(QByteArray {"Hello world!"});
         auto createItem = new Akonadi::ItemCreateJob(item, inboxSourceCol, this);
         AKVERIFYEXEC(createItem);
         item = createItem->item();
@@ -439,7 +426,7 @@ private Q_SLOTS:
         Akonadi::Item item;
         item.setMimeType(QStringLiteral("application/octet-stream"));
         item.setParentCollection(inboxSourceCol);
-        item.setPayload(QByteArray{"Hello world!"});
+        item.setPayload(QByteArray {"Hello world!"});
         auto createItem = new Akonadi::ItemCreateJob(item, inboxSourceCol, this);
         AKVERIFYEXEC(createItem);
         item = createItem->item();
@@ -513,7 +500,7 @@ private Q_SLOTS:
         Akonadi::Item item;
         item.setMimeType(QStringLiteral("application/octet-stream"));
         item.setParentCollection(inboxSourceCol);
-        item.setPayload(QByteArray{"Hello world!"});
+        item.setPayload(QByteArray {"Hello world!"});
         auto createItem = new Akonadi::ItemCreateJob(item, inboxSourceCol, this);
         AKVERIFYEXEC(createItem);
         item = createItem->item();
