@@ -1,18 +1,7 @@
 /*
-  Copyright (c) 2013-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
 
-  This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License, version 2, as
-  published by the Free Software Foundation.
-
-  This program is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+  SPDX-License-Identifier: GPL-2.0-only
 */
 
 #include "configureaccountpage.h"
@@ -28,7 +17,6 @@
 using namespace PimCommon::ConfigureImmutableWidgetUtils;
 #include <MailTransport/TransportManagementWidget>
 using MailTransport::TransportManagementWidget;
-#include "ui_accountspagereceivingtab.h"
 #include <MailCommon/MailUtil>
 
 #include <AkonadiCore/agentfilterproxymodel.h>
@@ -65,32 +53,31 @@ AccountsPage::AccountsPage(QWidget *parent)
     : ConfigModuleWithTabs(parent)
 {
     //Identity Tab:
-    KMail::IdentityPage *identityTab = new KMail::IdentityPage();
+    auto *identityTab = new KMail::IdentityPage();
     addTab(identityTab, i18nc("@title:tab Tab page where the user configures identities", "Identities"));
 
     //
     // "Receiving" tab:
     //
-    ReceivingTab *receivingTab = new ReceivingTab();
+    auto *receivingTab = new ReceivingTab();
     addTab(receivingTab, i18nc("@title:tab Tab page where the user configures accounts to receive mail", "Receiving"));
     connect(receivingTab, &ReceivingTab::accountListChanged, this, &AccountsPage::accountListChanged);
 
     //
     // "Sending" tab:
     //
-    SendingTab *sendingTab = new SendingTab();
+    auto *sendingTab = new SendingTab();
     addTab(sendingTab, i18nc("@title:tab Tab page where the user configures accounts to send mail", "Sending"));
 
     //
     // "Sending" tab:
     //
-    LdapCompetionTab *ldapCompletionTab = new LdapCompetionTab();
+    auto *ldapCompletionTab = new LdapCompetionTab();
     addTab(ldapCompletionTab, i18nc("@title:tab Tab page where the user configures ldap server", "LDAP server"));
 }
 
 AccountsPageSendingTab::~AccountsPageSendingTab()
-{
-}
+= default;
 
 QString AccountsPage::SendingTab::helpAnchor() const
 {
@@ -100,12 +87,12 @@ QString AccountsPage::SendingTab::helpAnchor() const
 AccountsPageSendingTab::AccountsPageSendingTab(QWidget *parent)
     : ConfigModuleTab(parent)
 {
-    QVBoxLayout *vlay = new QVBoxLayout(this);
+    auto *vlay = new QVBoxLayout(this);
     // label: zero stretch ### FIXME more
     vlay->addWidget(new QLabel(i18n("Outgoing accounts (add at least one):"), this));
 
-    TransportManagementWidget *tmw = new TransportManagementWidget(this);
-    tmw->layout()->setContentsMargins(0, 0, 0, 0);
+    auto *tmw = new TransportManagementWidget(this);
+    tmw->layout()->setContentsMargins({});
     vlay->addWidget(tmw);
 
     // "Common options" groupbox:
@@ -113,7 +100,7 @@ AccountsPageSendingTab::AccountsPageSendingTab(QWidget *parent)
     vlay->addWidget(group);
 
     // a grid layout for the contents of the "common options" group box
-    QGridLayout *glay = new QGridLayout();
+    auto *glay = new QGridLayout();
     group->setLayout(glay);
     glay->setColumnStretch(2, 10);
 
@@ -228,7 +215,7 @@ AccountsPageReceivingTab::AccountsPageReceivingTab(QWidget *parent)
         KConfigGroup grp = specialMailCollection.group(QStringLiteral("SpecialCollections"));
         mAccountsReceiving.mAccountsReceiving->setSpecialCollectionIdentifier(grp.readEntry(QStringLiteral("DefaultResourceId")));
     }
-    ConfigAgentDelegate *configDelegate = new ConfigAgentDelegate(mAccountsReceiving.mAccountsReceiving->view());
+    auto *configDelegate = new ConfigAgentDelegate(mAccountsReceiving.mAccountsReceiving->view());
     mAccountsReceiving.mAccountsReceiving->setItemDelegate(configDelegate);
     connect(configDelegate, &ConfigAgentDelegate::optionsClicked, this, &AccountsPageReceivingTab::slotShowMailCheckMenu);
 
@@ -237,7 +224,7 @@ AccountsPageReceivingTab::AccountsPageReceivingTab(QWidget *parent)
     connect(mAccountsReceiving.mOtherNewMailActionsButton, &QAbstractButton::clicked, this, &AccountsPageReceivingTab::slotEditNotifications);
     connect(mAccountsReceiving.customizeAccountOrder, &QAbstractButton::clicked, this, &AccountsPageReceivingTab::slotCustomizeAccountOrder);
     mAccountsReceiving.mAccountsReceiving->disconnectAddAccountButton();
-    QMenu *accountMenu = new QMenu(this);
+    auto *accountMenu = new QMenu(this);
     accountMenu->addAction(i18n("Add Mail Account..."), this, &AccountsPageReceivingTab::slotAddMailAccount);
     accountMenu->addAction(i18n("Custom Account..."), this, &AccountsPageReceivingTab::slotAddCustomAccount);
     mAccountsReceiving.mAccountsReceiving->addAccountButton()->setMenu(accountMenu);
@@ -339,7 +326,7 @@ void AccountsPageReceivingTab::slotShowMailCheckMenu(const QString &ident, const
 
 void AccountsPageReceivingTab::slotCheckOnStatupChanged(bool checked)
 {
-    QAction *action = qobject_cast< QAction * >(sender());
+    auto *action = qobject_cast< QAction * >(sender());
     const QString ident = action->data().toString();
 
     QSharedPointer<RetrievalOptions> opts = mRetrievalHash.value(ident);
@@ -349,7 +336,7 @@ void AccountsPageReceivingTab::slotCheckOnStatupChanged(bool checked)
 
 void AccountsPageReceivingTab::slotIncludeInCheckChanged(bool checked)
 {
-    QAction *action = qobject_cast< QAction * >(sender());
+    auto *action = qobject_cast< QAction * >(sender());
     const QString ident = action->data().toString();
 
     QSharedPointer<RetrievalOptions> opts = mRetrievalHash.value(ident);
@@ -359,7 +346,7 @@ void AccountsPageReceivingTab::slotIncludeInCheckChanged(bool checked)
 
 void AccountsPageReceivingTab::slotOfflineOnShutdownChanged(bool checked)
 {
-    QAction *action = qobject_cast< QAction * >(sender());
+    auto *action = qobject_cast< QAction * >(sender());
     QString ident = action->data().toString();
 
     QSharedPointer<RetrievalOptions> opts = mRetrievalHash.value(ident);
@@ -371,7 +358,7 @@ void AccountsPage::ReceivingTab::slotEditNotifications()
 {
     const auto instance = Akonadi::AgentManager::self()->instance(QStringLiteral("akonadi_newmailnotifier_agent"));
     if (instance.isValid()) {
-        std::unique_ptr<Akonadi::AgentConfigurationDialog>(new Akonadi::AgentConfigurationDialog(instance, this))->exec();
+        std::make_unique<Akonadi::AgentConfigurationDialog>(instance, this)->exec();
     } else {
         KMessageBox::error(this, i18n("New Mail Notifier Agent not registered. Please contact your administrator."));
     }
@@ -414,8 +401,8 @@ void AccountsPage::ReceivingTab::save()
 LdapCompetionTab::LdapCompetionTab(QWidget *parent)
     : ConfigModuleTab(parent)
 {
-    QVBoxLayout *layout = new QVBoxLayout(this);
-    layout->setContentsMargins(0, 0, 0, 0);
+    auto *layout = new QVBoxLayout(this);
+    layout->setContentsMargins({});
 
     mLdapConfigureWidget = new KLDAP::LdapConfigureWidget(this);
     layout->addWidget(mLdapConfigureWidget);
@@ -424,8 +411,7 @@ LdapCompetionTab::LdapCompetionTab(QWidget *parent)
 }
 
 LdapCompetionTab::~LdapCompetionTab()
-{
-}
+= default;
 
 QString LdapCompetionTab::helpAnchor() const
 {
