@@ -1,18 +1,7 @@
 /*
-  Copyright (C) 2016-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2016-2020 Laurent Montel <montel@kde.org>
 
-  This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License, version 2, as
-  published by the Free Software Foundation.
-
-  This program is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+  SPDX-License-Identifier: GPL-2.0-only
 */
 
 #include "configurepluginslistwidget.h"
@@ -30,7 +19,6 @@
 #include <MessageComposer/PluginEditorGrammarManager>
 #include <PimCommon/GenericPluginManager>
 #include <AkonadiCore/ServerManager>
-#include <PimCommon/PluginUtil>
 #include <PimCommon/CustomToolsPlugin>
 #include <KSharedConfig>
 #include <KLocalizedString>
@@ -114,8 +102,7 @@ ConfigurePluginsListWidget::ConfigurePluginsListWidget(QWidget *parent)
 }
 
 ConfigurePluginsListWidget::~ConfigurePluginsListWidget()
-{
-}
+= default;
 
 void ConfigurePluginsListWidget::save()
 {
