@@ -1,20 +1,6 @@
-/* Copyright 2010 Thomas McGuire <mcguire@kde.org>
+/* SPDX-FileCopyrightText: 2010 Thomas McGuire <mcguire@kde.org>
 
-   This program is free software; you can redistribute it and/or
-   modify it under the terms of the GNU General Public License as
-   published by the Free Software Foundation; either version 2 of
-   the License or (at your option) version 3 or any later version
-   accepted by the membership of KDE e.V. (or its successor approved
-   by the membership of KDE e.V.), which shall act as a proxy
-   defined in Section 14 of version 3 of the license.
-
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-   GNU General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with this program.  If not, see <https://www.gnu.org/licenses/>.
+   SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 */
 #ifndef FOLDERSHORTCUTACTIONMANAGER_H
 #define FOLDERSHORTCUTACTIONMANAGER_H
@@ -52,8 +38,8 @@ Q_SIGNALS:
 
 private:
     Q_DISABLE_COPY(FolderShortcutCommand)
-    Akonadi::Collection mCollectionFolder;
-    QWidget *mMainWidget = nullptr;
+    const Akonadi::Collection mCollectionFolder;
+    QWidget *const mMainWidget;
     QAction *mAction = nullptr;
 };
 
