@@ -1,18 +1,7 @@
 /*
-  Copyright (c) 2012-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2012-2020 Laurent Montel <montel@kde.org>
 
-  This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License, version 2, as
-  published by the Free Software Foundation.
-
-  This program is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+  SPDX-License-Identifier: GPL-2.0-only
 */
 
 #include "identityaddvcarddialog.h"
@@ -34,7 +23,7 @@ IdentityAddVcardDialog::IdentityAddVcardDialog(const QStringList &shadowIdentiti
 {
     setWindowTitle(i18nc("@title:window", "Create own vCard"));
     QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel, this);
-    QVBoxLayout *mainLayout = new QVBoxLayout(this);
+    auto *mainLayout = new QVBoxLayout(this);
     QPushButton *okButton = buttonBox->button(QDialogButtonBox::Ok);
     okButton->setDefault(true);
     okButton->setShortcut(Qt::CTRL | Qt::Key_Return);
@@ -46,8 +35,8 @@ IdentityAddVcardDialog::IdentityAddVcardDialog(const QStringList &shadowIdentiti
     mainLayout->addWidget(mainWidget);
     mainLayout->addWidget(buttonBox);
 
-    QVBoxLayout *vlay = new QVBoxLayout(mainWidget);
-    vlay->setContentsMargins(0, 0, 0, 0);
+    auto *vlay = new QVBoxLayout(mainWidget);
+    vlay->setContentsMargins({});
 
     mButtonGroup = new QButtonGroup(this);
     mButtonGroup->setObjectName(QStringLiteral("buttongroup"));
@@ -64,7 +53,7 @@ IdentityAddVcardDialog::IdentityAddVcardDialog(const QStringList &shadowIdentiti
     mButtonGroup->addButton(fromExistingVCard, static_cast<int>(FromExistingVCard));
 
     // row 3: KUrlRequester
-    QHBoxLayout *hlay = new QHBoxLayout(); // inherits spacing
+    auto *hlay = new QHBoxLayout(); // inherits spacing
     vlay->addLayout(hlay);
 
     mVCardPath = new KUrlRequester(this);
@@ -113,8 +102,7 @@ IdentityAddVcardDialog::IdentityAddVcardDialog(const QStringList &shadowIdentiti
 }
 
 IdentityAddVcardDialog::~IdentityAddVcardDialog()
-{
-}
+= default;
 
 IdentityAddVcardDialog::DuplicateMode IdentityAddVcardDialog::duplicateMode() const
 {
