@@ -1,21 +1,9 @@
 /*
   This file is part of KMail, the KDE mail client.
-  Copyright (c) 1997 Markus Wuebben <markus.wuebben@kde.org>
-  Copyright (c) 2009-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 1997 Markus Wuebben <markus.wuebben@kde.org>
+  SPDX-FileCopyrightText: 2009-2020 Laurent Montel <montel@kde.org>
 
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-  GNU General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+  SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 // define this to copy all html that is written to the readerwindow to
@@ -49,7 +37,6 @@ using MessageViewer::CSSHelper;
 #include <kmime/kmime_mdn.h>
 #include <akonadi/kmime/messageflags.h>
 
-#include <MessageViewer/Viewer>
 using namespace MessageViewer;
 #include <MessageCore/MessageCoreSettings>
 
@@ -88,7 +75,7 @@ KMReaderWin::KMReaderWin(QWidget *aParent, QWidget *mainWindow, KActionCollectio
     , mActionCollection(actionCollection)
 {
     createActions();
-    QVBoxLayout *vlay = new QVBoxLayout(this);
+    auto *vlay = new QVBoxLayout(this);
     vlay->setContentsMargins(0, 4, 0, 0);
     mViewer = new Viewer(this, mainWindow, mActionCollection);
     connect(mViewer, qOverload<const Akonadi::Item &, const QUrl &>(&Viewer::urlClicked), this, &KMReaderWin::slotUrlClicked);
@@ -225,8 +212,7 @@ bool KMReaderWin::isFixedFont() const
 }
 
 KMReaderWin::~KMReaderWin()
-{
-}
+= default;
 
 void KMReaderWin::readConfig()
 {
@@ -278,6 +264,8 @@ static const char *const kmailNewFeatures[] = {
     I18N_NOOP("Plugins support"),
     I18N_NOOP("New HTML renderer (QtWebEngine)"),
     I18N_NOOP("Added Check for Phishing URL"),
+    I18N_NOOP("Added Check DKIM"),
+    I18N_NOOP("Added Markdown Editing Support"),
 };
 static const int numKMailNewFeatures
     = sizeof kmailNewFeatures / sizeof *kmailNewFeatures;
@@ -423,7 +411,7 @@ bool KMReaderWin::htmlLoadExternal()
     return mViewer->htmlLoadExternal();
 }
 
-Akonadi::Item KMReaderWin::message() const
+Akonadi::Item KMReaderWin::messageItem() const
 {
     return mViewer->messageItem();
 }
@@ -435,14 +423,14 @@ QWidget *KMReaderWin::mainWindow() const
 
 void KMReaderWin::slotMailtoCompose()
 {
-    KMCommand *command = new KMMailtoComposeCommand(urlClicked(), message());
+    KMCommand *command = new KMMailtoComposeCommand(urlClicked(), messageItem());
     command->start();
 }
 
 void KMReaderWin::slotMailtoForward()
 {
     KMCommand *command = new KMMailtoForwardCommand(mMainWindow, urlClicked(),
-                                                    message());
+                                                    messageItem());
     command->start();
 }
 
@@ -454,10 +442,10 @@ void KMReaderWin::slotMailtoAddAddrBook()
     }
     const QString emailString = KEmailAddress::decodeMailtoUrl(url);
 
-    Akonadi::AddEmailAddressJob *job = new Akonadi::AddEmailAddressJob(emailString, mMainWindow, this);
+    auto *job = new Akonadi::AddEmailAddressJob(emailString, mMainWindow, this);
     job->setInteractive(true);
-    connect(job, &Akonadi::AddEmailAddressJob::successMessage, this, [this](const QString &message) {
-         PimCommon::BroadcastStatus::instance()->setStatusMsg(message);
+    connect(job, &Akonadi::AddEmailAddressJob::successMessage, this, [](const QString &message) {
+        PimCommon::BroadcastStatus::instance()->setStatusMsg(message);
     });
     job->start();
 }
@@ -473,7 +461,7 @@ void KMReaderWin::slotMailToAddToExistingContact()
     if (dlg->exec()) {
         Akonadi::Item item = dlg->selectedContact();
         if (item.isValid()) {
-            AddEmailToExistingContactJob *job = new AddEmailToExistingContactJob(item, emailString, this);
+            auto *job = new AddEmailToExistingContactJob(item, emailString, this);
             job->start();
         }
     }
@@ -488,7 +476,7 @@ void KMReaderWin::slotMailtoOpenAddrBook()
     }
     const QString emailString = KEmailAddress::decodeMailtoUrl(url).toLower();
 
-    Akonadi::OpenEmailAddressJob *job = new Akonadi::OpenEmailAddressJob(emailString, mMainWindow, this);
+    auto *job = new Akonadi::OpenEmailAddressJob(emailString, mMainWindow, this);
     job->start();
 }
 
@@ -525,7 +513,7 @@ void KMReaderWin::slotSaveImageOnDisk()
 void KMReaderWin::slotMailtoReply()
 {
     KMMailtoReplyCommand *command = new KMMailtoReplyCommand(mMainWindow, urlClicked(),
-                                                  message(), copyText());
+                                                             messageItem(), copyText());
     command->setReplyAsHtml(htmlMail());
     command->start();
 }
@@ -752,10 +740,10 @@ bool KMReaderWin::printSelectedText(bool preview)
     if (str.isEmpty()) {
         return false;
     }
-    ::MessageComposer::Composer *composer = new ::MessageComposer::Composer;
+    auto *composer = new ::MessageComposer::Composer;
     composer->textPart()->setCleanPlainText(str);
     composer->textPart()->setWrappedPlainText(str);
-    KMime::Message::Ptr messagePtr = message().payload<KMime::Message::Ptr>();
+    KMime::Message::Ptr messagePtr = messageItem().payload<KMime::Message::Ptr>();
     composer->infoPart()->setFrom(messagePtr->from()->asUnicodeString());
     composer->infoPart()->setTo(QStringList() << messagePtr->to()->asUnicodeString());
     composer->infoPart()->setCc(QStringList() << messagePtr->cc()->asUnicodeString());
@@ -769,7 +757,7 @@ bool KMReaderWin::printSelectedText(bool preview)
 void KMReaderWin::slotPrintComposeResult(KJob *job)
 {
     const bool preview = job->property("preview").toBool();
-    ::MessageComposer::Composer *composer = dynamic_cast< ::MessageComposer::Composer * >(job);
+    auto *composer = qobject_cast< ::MessageComposer::Composer * >(job);
     Q_ASSERT(composer);
     if (composer->error() == ::MessageComposer::Composer::NoError) {
         Q_ASSERT(composer->resultMessages().size() == 1);
@@ -790,7 +778,7 @@ void KMReaderWin::slotPrintComposeResult(KJob *job)
         commandInfo.mShowSignatureDetails = mViewer->showSignatureDetails() || MessageViewer::MessageViewerSettings::self()->alwaysShowEncryptionSignatureDetails();
         commandInfo.mShowEncryptionDetails = mViewer->showEncryptionDetails() || MessageViewer::MessageViewerSettings::self()->alwaysShowEncryptionSignatureDetails();
 
-        KMPrintCommand *command = new KMPrintCommand(this, commandInfo);
+        auto *command = new KMPrintCommand(this, commandInfo);
         command->start();
     } else {
         if (static_cast<KIO::Job *>(job)->uiDelegate()) {
@@ -843,7 +831,7 @@ void KMReaderWin::slotContactHtmlOptions()
     }
     const QString emailString = KEmailAddress::decodeMailtoUrl(url).toLower();
 
-    Akonadi::AddEmailDisplayJob *job = new Akonadi::AddEmailDisplayJob(emailString, mMainWindow, this);
+    auto *job = new Akonadi::AddEmailDisplayJob(emailString, mMainWindow, this);
     job->setMessageId(mViewer->messageItem().id());
     connect(job, &Akonadi::AddEmailDisplayJob::contactUpdated, this, &KMReaderWin::slotContactHtmlPreferencesUpdated);
     job->setRemoteContent(mLoadExternalReference->isChecked());
